Package: industRial
Type: Package
Date: 2021-06-04
Title: Data, Functions and Support Materials from the Book "industRial
        Data Science"
Version: 0.1.0
Authors@R: person("Joao", "Ramalho", email = "ramalho.joao@protonmail.com", role = c("aut", "cre"))
Description: Companion package to the book "industRial data science", 
    J.Ramalho (2021) <https://j-ramalho.github.io/industRial/>. 
    Provides data sets and functions to complete the case studies and contains 
    the book original Rmd files and tutorials.
URL: https://github.com/J-Ramalho/industRial
BugReports: https://github.com/J-Ramalho/industRial/issues
License: GPL (>= 3)
Encoding: UTF-8
LazyData: true
Imports: ggplot2, stats, dplyr, tidyr, magrittr, rlang, lattice,
        SixSigma
Depends: R (>= 3.5.0)
RoxygenNote: 7.1.1
Suggests: glue, tibble, stringr, scales, purrr, janitor, patchwork,
        forcats, broom, viridis, learnr, DoE.base, qcc, car, qicharts2,
        rsm, ggforce, ggraph, tidygraph, igraph, bookdown, rmarkdown,
        knitr, agricolae, RcmdrMisc, gt, skimr, ggtext
NeedsCompilation: no
Packaged: 2021-06-10 15:12:26 UTC; joao
Author: Joao Ramalho [aut, cre]
Maintainer: Joao Ramalho <ramalho.joao@protonmail.com>
Repository: CRAN
Date/Publication: 2021-06-11 09:40:02 UTC
Built: R 4.6.0; ; 2026-04-26 19:09:23 UTC; unix
