# Generated by roxygen2: do not edit by hand

export(chart_Cpk)
export(chart_I)
export(chart_IMR)
export(expand_formula)
export(off_spec)
export(process_Cpk)
export(process_stats)
export(process_stats_table)
export(ss.rr.plots)
export(theme_industRial)
export(theme_qcc)
importFrom(SixSigma,ss.cc.getd2)
importFrom(SixSigma,ss.cc.getd3)
importFrom(ggplot2,"%+replace%")
importFrom(magrittr,"%>%")
importFrom(rlang,.data)
importFrom(stats,aggregate)
importFrom(stats,aov)
importFrom(stats,as.formula)
importFrom(stats,pf)
