
echo "# IndustrialStatistics" >> README.md
git init
git add README.md
git commit -m "first commit"
git remote add origin https://github.com/J-Ramalho/IndustrialStatistics.git
git push -u origin master
                

find -type f -name "render*.rds" -delete
